@@ -22,10 +22,10 @@
 
 #include "MD5Info.ih"
 
-MD5Info &MD5Info::getInstance()
-{
-  OpenMP::ScopedLock instantiateLock(s_instanceLock);
-	if(s_instance == 0)
-		s_instance = new MD5Info;
-	return *s_instance;
+MD5Info &MD5Info::getInstance() {
+    OpenMP::ScopedLock instantiateLock(s_instanceLock);
+    if(s_instance == 0) {
+        s_instance = new MD5Info;
+    }
+    return *s_instance;
 }
