@@ -1,5 +1,6 @@
 /*
   This file is part of ccbuild.
+  Copyright (C) 2013  A. Bram Neijt <bneijt@gmail.com>
 
   ccbuild is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -14,19 +15,14 @@
   You should have received a copy of the GNU General Public License
   along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
 */
-
-
-
-
-
-
 #include "source.ih"
 
-bool Source::producesOutput()	const
-{
-	if(isHeader() && Options::precompileAll)
-		return true;
-	if(isInternalHeader() && Options::precompile)
-		return true;
-	return hasSourceExtension();
+bool Source::producesOutput()   const {
+    if(isHeader() && Options::precompileAll) {
+        return true;
+    }
+    if(isInternalHeader() && Options::precompile) {
+        return true;
+    }
+    return hasSourceExtension();
 }
